// -*- mode: js; js-indent-level: 4; indent-tabs-mode: nil -*-
/*
  Copyright (C) 2012-2019  Dieter Schärf <ds@dschaerf.de>

  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program. If not, see <http://www.gnu.org/licenses/>.
*/

const Clutter = imports.gi.Clutter;
const Lang = imports.lang;
const St = imports.gi.St;

const ExtensionUtils = imports.misc.extensionUtils;
const Main = imports.ui.main;

const Me = ExtensionUtils.getCurrentExtension();

const Convenience = Me.imports.convenience;

const ACTIVITIES_DEFAULT = 0;
const ACTIVITIES_ICON = 1;
const ACTIVITIES_NONE = 2;

const KEY_SHOW_ACTIVITIES = 'show-activities';

const ActivitiesButton = new Lang.Class({
    Name: 'PanelManager.ActivitiesButton',

    _init: function() {
        this._changedActivities(true);
        this._settingsChangedId = Convenience.Settings.connect('changed::'+KEY_SHOW_ACTIVITIES, Lang.bind(this, this._onShowActivities));
    },

    _changedActivities: function(enabled) {
        if (enabled) {
            this._indicators = new St.BoxLayout({ style_class: 'panel-status-menu-box' });
            this._icon = new St.Icon({ icon_name: 'start-here-symbolic', style_class: 'system-status-icon' });
            this._indicators.add_child(this._icon);
            Main.panel.statusArea.activities.actor.remove_actor(Main.panel.statusArea.activities._label);
            this._indicators.add_child(Main.panel.statusArea.activities._label);
            Main.panel.statusArea.activities.actor.add_child(this._indicators);
            this._onShowActivities();
        } else {
            this._indicators.remove_actor(Main.panel.statusArea.activities._label);
            Main.panel.statusArea.activities.actor.remove_actor(this._indicators);
            Main.panel.statusArea.activities.actor.add_actor(Main.panel.statusArea.activities._label);
            this._setStyleParent(true);
        }
    },

    _onShowActivities: function() {
        let showActivities = Convenience.Settings.get_enum(KEY_SHOW_ACTIVITIES);
        this._icon.visible = showActivities === ACTIVITIES_ICON;
        Main.panel.statusArea.activities._label.visible = showActivities === ACTIVITIES_DEFAULT;
        this._setStyleParent(showActivities !== ACTIVITIES_NONE);
    },

    _setStyleParent: function(visible) {
        if (Main.panel.statusArea.activities.container.visible !== visible) {
            Main.panel.statusArea.activities.container.visible = visible;
            if (Main.panel.actor.get_text_direction() === Clutter.TextDirection.RTL) {
                Main.panel._leftCorner.setStyleParent.call(Main.panel._leftCorner, Main.panel._rightBox);
            } else {
                Main.panel._leftCorner.setStyleParent.call(Main.panel._leftCorner, Main.panel._leftBox);
            }
        }
    },

    destroy: function() {
        Convenience.Settings.disconnect(this._settingsChangedId);
        this._changedActivities(false);
    }
});

function getExtension() {
    return new ActivitiesButton();
}
