// -*- mode: js; js-indent-level: 4; indent-tabs-mode: nil -*-
/*
  Copyright (C) 2012-2019  Dieter Schärf <ds@dschaerf.de>

  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program. If not, see <http://www.gnu.org/licenses/>.
*/

const Lang = imports.lang;

const ExtensionUtils = imports.misc.extensionUtils;
const Main = imports.ui.main;
const StatusKeyboard = imports.ui.status.keyboard;

const Me = ExtensionUtils.getCurrentExtension();

const Convenience = Me.imports.convenience;

const KEY_SHOW_KEYBOARD = 'show-keyboard';

const PANELMENU_BUTTON_DEFAULT = 0;
const PANELMENU_BUTTON_SHOW = 1;

const KeyboardMenuButton = new Lang.Class({
    Name: 'PanelManager.KeyboardMenuButton',

    _init: function() {
        this._changedKeyboard(true);
        this._settingsChangedId = Convenience.Settings.connect('changed::'+KEY_SHOW_KEYBOARD, Lang.bind(this, this._onShowKeyboard));
        this._currentSourceChangedId = Main.panel.statusArea.keyboard._inputSourceManager.connect('current-source-changed', Lang.bind(this, this._onShowKeyboard));
    },

    _changedKeyboard: function(enabled) {
        if (enabled) {
            Main.panel.statusArea.keyboard._currentSourceChanged = function() {
                StatusKeyboard.InputSourceIndicator.prototype._currentSourceChanged.call(this);
                let pmShowButton = Convenience.Settings.get_enum(KEY_SHOW_KEYBOARD);
                if (pmShowButton !== PANELMENU_BUTTON_DEFAULT) {
                    let numInputSources = Object.keys(this._inputSourceManager.inputSources).length;
                    if (numInputSources > 0) {
                        this._menuItems[0].setSensitive(true);
                        if (numInputSources === 1) {
                            this._indicatorLabels[0].show();
                            this._menuItems[0].setSensitive(false);
                        }
                        this.actor.visible = pmShowButton === PANELMENU_BUTTON_SHOW;
                    }
                }
            }
        } else {
            Main.panel.statusArea.keyboard._currentSourceChanged = StatusKeyboard.InputSourceIndicator.prototype._currentSourceChanged;
        }
        this._onShowKeyboard();
    },

    _onShowKeyboard: function() {
        Main.panel.statusArea.keyboard._currentSourceChanged.call(Main.panel.statusArea.keyboard);
    },

    destroy: function() {
        Main.panel.statusArea.keyboard._inputSourceManager.disconnect(this._currentSourceChangedId);
        Convenience.Settings.disconnect(this._settingsChangedId);
        this._changedKeyboard(false);
    }
});

function getExtension() {
    return new KeyboardMenuButton();
}
